using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using ChartDirector;

namespace WindowsApplication1
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private int startDragX = -1;
        private int startDragY = -1;
        private int endDragX = -1;
        private int endDragY = -1;

        private void Form1_Load(object sender, EventArgs e)
        {
            drawChart(winChartViewer1);
        }

        //Main code for creating chart.
        //Note: the argument img is unused because this demo only has 1 chart.
        public void drawChart(WinChartViewer viewer)
        {
            // Create a finance chart demo containing 100 days of data
            int noOfDays = 100;

            // To compute moving averages starting from the first day, we need to get
            // extra data points before the first day
            int extraDays = 30;

            // In this exammple, we use a random number generator utility to simulate
            // the data. We set up the random table to create 6 cols x (noOfDays +
            // extraDays) rows, using 9 as the seed.
            RanTable rantable = new RanTable(9, 6, noOfDays + extraDays);

            // Set the 1st col to be the timeStamp, starting from Sep 4, 2002, with
            // each row representing one day, and counting week days only (jump over
            // Sat and Sun)
            rantable.setDateCol(0, new DateTime(2002, 9, 4), 86400, true);

            // Set the 2nd, 3rd, 4th and 5th columns to be high, low, open and close
            // data. The open value starts from 100, and the daily change is random
            // from -5 to 5.
            rantable.setHLOCCols(1, 100, -5, 5);

            // Set the 6th column as the vol data from 5 to 25 million
            rantable.setCol(5, 50000000, 250000000);

            // Now we read the data from the table into arrays
            double[] timeStamps = rantable.getCol(0);
            double[] highData = rantable.getCol(1);
            double[] lowData = rantable.getCol(2);
            double[] openData = rantable.getCol(3);
            double[] closeData = rantable.getCol(4);
            double[] volData = rantable.getCol(5);

            // Create a FinanceChart object of width 640 pixels
            FinanceChart c = new FinanceChart(800);

            // Add a title to the chart
            c.addTitle("Finance Chart Demonstration");

            // Set the data into the finance chart object
            c.setData(timeStamps, highData, lowData, openData, closeData, volData,
                extraDays);

            // Add the main chart with 240 pixels in height
            c.addMainChart(400);

            // Add a 10 period simple moving average to the main chart, using brown
            // color
            c.addSimpleMovingAvg(10, 0x663300);

            // Add a 20 period simple moving average to the main chart, using purple
            // color
            c.addSimpleMovingAvg(20, 0x9900ff);

            // Add candlestick symbols to the main chart, using green/red for up/down
            // days
            c.addCandleStick(0x00ff00, 0xff0000);

            // Add 20 days donchian channel to the main chart, using light blue
            // (9999ff) as the border and semi-transparent blue (c06666ff) as the
            // fill color
            c.addDonchianChannel(20, 0x9999ff, unchecked((int)0xc06666ff));

            // Add a 75 pixels volume bars sub-chart to the bottom of the main chart,
            // using green/red/grey for up/down/flat days
            c.addVolBars(75, 0x99ff99, 0xff9999, 0x808080);

            // Output the chart
            viewer.Chart = c;
        }

        private void winChartViewer1_Paint(object sender, PaintEventArgs e)
        {
            if (endDragX >= 0)
                e.Graphics.DrawLine(new Pen(Color.Black), startDragX, startDragY, endDragX, endDragY);
        }

        private void winChartViewer1_MouseDown(object sender, MouseEventArgs e)
        {
            startDragX = e.X;
            startDragY = e.Y;
        }

        private void winChartViewer1_MouseMove(object sender, MouseEventArgs e)
        {
            if (e.Button == MouseButtons.Left) {
                endDragX = e.X;
                endDragY = e.Y;
                winChartViewer1.updateDisplay();
            }
        }
    }
}